@@ -1,5 +1,6 @@
 /* Establishing and handling network connections.
-   Copyright (C) 1995-2011, 2015, 2018 Free Software Foundation, Inc.
+   Copyright (C) 1995-2011, 2015, 2018-2019 Free Software Foundation,
+   Inc.
 
 This file is part of GNU Wget.
 
@@ -70,7 +71,7 @@ as that of the covered work.  */
 # endif
 #endif /* ENABLE_IPV6 */
 
-/* Fill SA as per the data in IP and PORT.  SA shoult point to struct
+/* Fill SA as per the data in IP and PORT.  SA should point to struct
    sockaddr_storage if ENABLE_IPV6 is defined, to struct sockaddr_in
    otherwise.  */
 
@@ -714,7 +715,7 @@ select_fd (int fd, double maxtime, int wait_for)
   return result;
 }
 
-/* Return true iff the connection to the remote site established
+/* Return true if the connection to the remote site established
    through SOCK is still open.
 
    Specifically, this function returns true if SOCK is not ready for
@@ -1041,3 +1042,18 @@ fd_close (int fd)
       ++transport_map_modified_tick;
     }
 }
+
+void
+connect_cleanup(void)
+{
+  if (transport_map)
+    {
+      hash_table_iterator iter;
+      for (hash_table_iterate (transport_map, &iter); hash_table_iter_next (&iter); )
+        {
+          xfree (iter.value);
+        }
+      hash_table_destroy (transport_map);
+      transport_map = NULL;
+    }
+}
