@@ -1,6 +1,6 @@
 /* Declarations for css-url.c.
-   Copyright (C) 2006, 2009, 2010, 2011, 2015 Free Software Foundation,
-   Inc.
+   Copyright (C) 2006, 2009-2011, 2015, 2018-2019 Free Software
+   Foundation, Inc.
 
 This file is part of GNU Wget.
 
