@@ -1,6 +1,6 @@
 /* Declarations for res.c.
-   Copyright (C) 2001, 2007-2011, 2015, 2018 Free Software Foundation,
-   Inc.
+   Copyright (C) 2001, 2007-2011, 2015, 2018-2019 Free Software
+   Foundation, Inc.
 
 This file is part of Wget.
 
